@@ -61,14 +61,6 @@ def init_spark_session(conf=None, app_name="rikai", rikai_version=None):
                 ]
             ),
         )
-        .config(
-            # Sadly we have to use a shaded gcs connector due to guava
-            # conflicts with Spark 3.1
-            "spark.jars",
-            "https://repo1.maven.org/maven2/com/google/cloud/bigdataoss/"
-            "gcs-connector/hadoop3-2.2.2/"
-            "gcs-connector-hadoop3-2.2.2-shaded.jar",
-        )
         .config(
             "spark.sql.extensions",
             "ai.eto.rikai.sql.spark.RikaiSparkSessionExtensions",
